import "./TreeView.css";
import {ActionButtonGroupContext as $10401bdc118cbc90$export$33f5f2f2cb85d743} from "./ActionButtonGroup.mjs";
import {ActionMenuContext as $8bf3cd2442eb485e$export$7f4b66acaca28bd5} from "./ActionMenu.mjs";
import {centerBaseline as $1f4b04be3f24aae3$export$9d7e2342a7e53afa} from "./CenterBaseline.mjs";
import {Checkbox as $9b405e0f8095dce0$export$48513f6b9f8ce62d} from "./Checkbox.mjs";
import $4b69f02ec06b9226$export$2e2bcd8739ae039 from "./Chevron.mjs";
import {IconContext as $ac8c32e6775ddd1f$export$a49f528ae1a4d0ed} from "../icons/Icon.mjs";
import {TextContext as $8e847109a6ab556d$export$9afb8bc826b033ea} from "./Content.mjs";
import {useScale as $859432f3b3573fcb$export$a8d2043b2d807f4d} from "./utils.mjs";
import {jsx as $iOVFT$jsx, jsxs as $iOVFT$jsxs} from "react/jsx-runtime";
import {Virtualizer as $iOVFT$Virtualizer, ListLayout as $iOVFT$ListLayout, Tree as $iOVFT$Tree, TreeItem as $iOVFT$TreeItem, TreeItemContent as $iOVFT$TreeItemContent, Provider as $iOVFT$Provider, useContextProps as $iOVFT$useContextProps, ButtonContext as $iOVFT$ButtonContext, Button as $iOVFT$Button} from "react-aria-components";
import {isAndroid as $iOVFT$isAndroid} from "@react-aria/utils";
import {createContext as $iOVFT$createContext, useContext as $iOVFT$useContext, useRef as $iOVFT$useRef, forwardRef as $iOVFT$forwardRef} from "react";
import {useDOMRef as $iOVFT$useDOMRef} from "@react-spectrum/utils";
import {useLocale as $iOVFT$useLocale} from "react-aria";

/*
 * Copyright 2024 Adobe. All rights reserved.
 * This file is licensed to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License. You may obtain a copy
 * of the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under
 * the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR REPRESENTATIONS
 * OF ANY KIND, either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */ 













const $03960a2740ca2b19$var$TreeRendererContext = /*#__PURE__*/ (0, $iOVFT$createContext)({});
let $03960a2740ca2b19$var$InternalTreeContext = /*#__PURE__*/ (0, $iOVFT$createContext)({});
// TODO: the below is needed so the borders of the top and bottom row isn't cut off if the TreeView is wrapped within a container by always reserving the 2px needed for the
// keyboard focus ring. Perhaps find a different way of rendering the outlines since the top of the item doesn't
// scroll into view due to how the ring is offset. Alternatively, have the tree render the top/bottom outline like it does in Listview
const $03960a2740ca2b19$var$tree = function anonymous(props, overrides) {
    let rules = " ";
    let minHeight = false;
    let minWidth = false;
    let width = false;
    let height = false;
    let matches = (overrides || '').matchAll(/(?:^|\s)(J|G|I|H|_u|_v|_s|__A|_d|_J|z|y|B|A|_P|_9|W|_l|_A|_z|Z|N|L|F|M|K)[^\s]+/g);
    for (let p of matches){
        if (p[1] === "M") minHeight = true;
        if (p[1] === "N") minWidth = true;
        if (p[1] === "Z") width = true;
        if (p[1] === "F") height = true;
        rules += p[0];
    }
    if (props.isFocusVisible) rules += ' _Lf9';
    else rules += ' _Le9';
    rules += ' Oh9';
    rules += ' _Mc9';
    rules += ' _Kb9';
    rules += ' _4c9';
    if (!minHeight) rules += ' Ma9';
    if (!minWidth) rules += ' Na9';
    if (!width) rules += ' Za9';
    if (!height) rules += ' Fb9';
    rules += ' _Na9';
    rules += ' Pa9';
    rules += ' _oa9';
    if (props.isEmpty) rules += ' _Ca9';
    if (props.isEmpty) rules += ' eb9';
    rules += ' -lPUMEc-Zu9';
    return rules;
};
function $03960a2740ca2b19$var$TreeView(props, ref) {
    let { children: children, isDetached: isDetached, isEmphasized: isEmphasized, UNSAFE_className: UNSAFE_className, UNSAFE_style: UNSAFE_style } = props;
    let scale = (0, $859432f3b3573fcb$export$a8d2043b2d807f4d)();
    let renderer;
    if (typeof children === 'function') renderer = children;
    let domRef = (0, $iOVFT$useDOMRef)(ref);
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Virtualizer), {
        layout: (0, $iOVFT$ListLayout),
        layoutOptions: {
            rowHeight: scale === 'large' ? 50 : 40,
            gap: isDetached ? 2 : 0
        },
        children: /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$TreeRendererContext.Provider, {
            value: {
                renderer: renderer
            },
            children: /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$InternalTreeContext.Provider, {
                value: {
                    isDetached: isDetached,
                    isEmphasized: isEmphasized
                },
                children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Tree), {
                    ...props,
                    style: UNSAFE_style,
                    className: (renderProps)=>(UNSAFE_className ?? '') + $03960a2740ca2b19$var$tree({
                            isDetached: isDetached,
                            ...renderProps
                        }, props.styles),
                    selectionBehavior: "toggle",
                    ref: domRef,
                    children: props.children
                })
            })
        })
    });
}
const $03960a2740ca2b19$var$selectedBackground = "[light-dark(color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(59, 99, 251), rgb(86, 129, 255)) 10%), color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(93, 137, 255), rgb(52, 91, 248)) 10%))]";
const $03960a2740ca2b19$var$selectedActiveBackground = "[light-dark(color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(59, 99, 251), rgb(86, 129, 255)) 15%), color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(93, 137, 255), rgb(52, 91, 248)) 15%))]";
const $03960a2740ca2b19$var$rowBackgroundColor = {
    default: '--s2-container-bg',
    isFocusVisibleWithin: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
    isHovered: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
    isPressed: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
    isSelected: {
        default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 7%)]",
        isEmphasized: $03960a2740ca2b19$var$selectedBackground,
        isFocusVisibleWithin: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        },
        isHovered: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        },
        isPressed: {
            default: "[color-mix(in srgb, light-dark(rgb(255, 255, 255), rgb(17, 17, 17)), light-dark(rgb(19, 19, 19), rgb(242, 242, 242)) 10%)]",
            isEmphasized: $03960a2740ca2b19$var$selectedActiveBackground
        }
    },
    forcedColors: {
        default: 'Background'
    }
};
const $03960a2740ca2b19$var$treeRow = function anonymous(props) {
    let rules = " ";
    rules += ' _Pc9';
    rules += ' sd9';
    rules += ' Fv9';
    rules += ' Za9';
    rules += ' _oa9';
    rules += ' ug9';
    rules += ' uch9';
    rules += ' udi9';
    rules += ' uea9';
    rules += ' ugb9';
    rules += ' uhd9';
    rules += ' uje9';
    rules += ' uic9';
    rules += ' vd9';
    rules += ' vsf9';
    rules += ' wb9';
    rules += ' xb9';
    rules += ' _xa9';
    rules += ' _Fa9';
    rules += ' _Ffb9';
    rules += ' pt9';
    rules += ' _Le9';
    if (props.isLink) rules += ' ry9';
    else rules += ' ri9';
    if (props.isSelected) {
        if (props.isPressed) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd9';
            else rules += ' -qH4xad-gRfT7e9';
        } else if (props.isHovered) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd9';
            else rules += ' -qH4xad-gRfT7e9';
        } else if (props.isFocusVisibleWithin) {
            if (props.isEmphasized) rules += ' -qH4xad-gT9rOHd9';
            else rules += ' -qH4xad-gRfT7e9';
        } else if (props.isEmphasized) rules += ' -qH4xad-gJpow3b9';
        else rules += ' -qH4xad-gj1B7i9';
    } else if (props.isPressed) rules += ' -qH4xad-gRfT7e9';
    else if (props.isHovered) rules += ' -qH4xad-gj1B7i9';
    else if (props.isFocusVisibleWithin) rules += ' -qH4xad-gj1B7i9';
    else rules += ' -qH4xad-gEzkoQe9';
    rules += ' -qH4xad-lga9';
    rules += ' -_34HbNb-Oh9';
    rules += ' -_34HbNb-lOc9';
    return rules;
};
const $03960a2740ca2b19$var$treeCellGrid = function anonymous(props) {
    let rules = " ";
    rules += ' se9';
    rules += ' Za9';
    rules += ' Fb9';
    rules += ' _oa9';
    rules += ' _cb9';
    rules += ' eb9';
    rules += ' Dw9uTxc9';
    rules += ' EM8Mfn9';
    rules += ' CgjMZ2c9';
    rules += ' gs9yXOb9';
    rules += ' Rp9';
    if (props.isDisabled) {
        rules += ' pp9';
        rules += ' plc9';
    }
    if (props.isFocusVisible) rules += ' -_7xg3bb-Oh9';
    else rules += ' -_7xg3bb-O8Izf8c9';
    rules += ' -_7xg3bb-lOc9';
    rules += ' -pKMv1c-Oh9';
    rules += ' -pKMv1c-lOc9';
    if (props.isDetached) {
        if (props.isSelected) rules += ' iBGbjub9';
        else rules += ' iA9';
    }
    if (props.isDetached) rules += ' _kb9';
    if (props.isDetached) rules += ' hb9';
    if (props.isDetached) rules += ' mb9';
    if (props.isDetached) rules += ' lb9';
    if (props.isDetached) rules += ' ob9';
    if (props.isDetached) rules += ' nb9';
    if (props.isDetached) rules += ' kb9';
    if (props.isDetached) rules += ' jb9';
    if (props.isDetached) rules += ' _jf9';
    return rules;
};
const $03960a2740ca2b19$var$treeCheckbox = " zoRzcu9 yoRzcu9 BoRzcu9 AoRzcu9 Ix9 Hy9 Rd9";
const $03960a2740ca2b19$var$treeIcon = " z2U5Crc9 y2U5Crc9 B2U5Crc9 A2U5Crc9 Ht9 Hsu9 -_8sjo0b-t5ZbAob9";
const $03960a2740ca2b19$var$treeContent = " zk52g2d9 yk52g2d9 Bk52g2d9 Ak52g2d9 _Yb9 _7c9 _Nc9 Pc9";
const $03960a2740ca2b19$var$treeActions = " zkG38H9 ykG38H9 BkG38H9 AkG38H9 Ir9 Hs9";
const $03960a2740ca2b19$var$treeActionMenu = " z6Nrfjc9 y6Nrfjc9 B6Nrfjc9 A6Nrfjc9";
const $03960a2740ca2b19$var$cellFocus = {
    outlineStyle: {
        default: 'none',
        isFocusVisible: 'solid'
    },
    outlineOffset: -2,
    outlineWidth: 2,
    outlineColor: 'focus-ring',
    borderRadius: '[6px]'
};
const $03960a2740ca2b19$var$treeRowFocusIndicator = "tDhuzb";
const $03960a2740ca2b19$export$6e77ea6719814e9c = (props)=>{
    let { href: href } = props;
    let { isDetached: isDetached, isEmphasized: isEmphasized } = (0, $iOVFT$useContext)($03960a2740ca2b19$var$InternalTreeContext);
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$TreeItem), {
        ...props,
        className: (renderProps)=>$03960a2740ca2b19$var$treeRow({
                ...renderProps,
                isLink: !!href,
                isEmphasized: isEmphasized
            }) + (renderProps.isFocusVisible && !isDetached ? ' ' + $03960a2740ca2b19$var$treeRowFocusIndicator : '')
    });
};
const $03960a2740ca2b19$export$9a5779ed3fade674 = (props1)=>{
    let { children: children } = props1;
    let { isDetached: isDetached, isEmphasized: isEmphasized } = (0, $iOVFT$useContext)($03960a2740ca2b19$var$InternalTreeContext);
    let scale = (0, $859432f3b3573fcb$export$a8d2043b2d807f4d)();
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$TreeItemContent), {
        children: ({ isExpanded: isExpanded, hasChildItems: hasChildItems, selectionMode: selectionMode, selectionBehavior: selectionBehavior, isDisabled: isDisabled, isFocusVisible: isFocusVisible, isSelected: isSelected, id: id, state: state })=>{
            let isNextSelected = false;
            let isNextFocused = false;
            let keyAfter = state.collection.getKeyAfter(id);
            if (keyAfter != null) isNextSelected = state.selectionManager.isSelected(keyAfter);
            let isFirst = state.collection.getFirstKey() === id;
            return /*#__PURE__*/ (0, $iOVFT$jsxs)("div", {
                className: $03960a2740ca2b19$var$treeCellGrid({
                    isDisabled: isDisabled,
                    isNextSelected: isNextSelected,
                    isSelected: isSelected,
                    isFirst: isFirst,
                    isNextFocused: isNextFocused,
                    isDetached: isDetached
                }),
                children: [
                    selectionMode !== 'none' && selectionBehavior === 'toggle' && // TODO: add transition?
                    /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        className: $03960a2740ca2b19$var$treeCheckbox,
                        children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $9b405e0f8095dce0$export$48513f6b9f8ce62d), {
                            isEmphasized: isEmphasized,
                            slot: "selection"
                        })
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        className: " z7fSmKc9 y7fSmKc9 B7fSmKc9 A7fSmKc9 ZecPNad9"
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)($03960a2740ca2b19$var$ExpandableRowChevron, {
                        isDisabled: isDisabled,
                        isExpanded: isExpanded,
                        scale: scale,
                        isHidden: !hasChildItems
                    }),
                    /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Provider), {
                        values: [
                            [
                                (0, $8e847109a6ab556d$export$9afb8bc826b033ea),
                                {
                                    styles: $03960a2740ca2b19$var$treeContent
                                }
                            ],
                            [
                                (0, $ac8c32e6775ddd1f$export$a49f528ae1a4d0ed),
                                {
                                    render: (0, $1f4b04be3f24aae3$export$9d7e2342a7e53afa)({
                                        slot: 'icon',
                                        styles: $03960a2740ca2b19$var$treeIcon
                                    }),
                                    styles: " ZuUmpre9 FuUmpre9 _va9"
                                }
                            ],
                            [
                                (0, $10401bdc118cbc90$export$33f5f2f2cb85d743),
                                {
                                    styles: $03960a2740ca2b19$var$treeActions
                                }
                            ],
                            [
                                (0, $8bf3cd2442eb485e$export$7f4b66acaca28bd5),
                                {
                                    styles: $03960a2740ca2b19$var$treeActionMenu,
                                    isQuiet: true
                                }
                            ]
                        ],
                        children: children
                    }),
                    isFocusVisible && isDetached && /*#__PURE__*/ (0, $iOVFT$jsx)("div", {
                        role: "presentation",
                        className: function anonymous(props) {
                            let rules = " ";
                            if (props.isFocusVisible) rules += ' _Lf9';
                            else rules += ' _Le9';
                            rules += ' _Kb9';
                            rules += ' _Mc9';
                            rules += ' Oh9';
                            rules += ' of9';
                            rules += ' nf9';
                            rules += ' kf9';
                            rules += ' jf9';
                            rules += ' _Pa9';
                            rules += ' Wr9';
                            rules += ' _lr9';
                            rules += ' _Ar9';
                            rules += ' _zr9';
                            return rules;
                        }({
                            isFocusVisible: true
                        })
                    })
                ]
            });
        }
    });
};
const $03960a2740ca2b19$var$expandButton = function anonymous(props) {
    let rules = " ";
    rules += ' z8dW5Qb9';
    rules += ' y8dW5Qb9';
    rules += ' B8dW5Qb9';
    rules += ' A8dW5Qb9';
    if (props.isDisabled) {
        rules += ' pp9';
        rules += ' plc9';
    } else rules += ' p40ub4c9';
    rules += ' Fv9';
    rules += ' Zw9';
    rules += ' sd9';
    rules += ' _wb9';
    rules += ' _cb9';
    rules += ' _Ca9';
    rules += ' _Le9';
    rules += ' ri9';
    if (props.isExpanded) {
        if (props.isRTL) rules += ' _Za9';
        else rules += ' _Zb9';
    }
    rules += ' Td9';
    rules += ' Qd9';
    rules += ' Sd9';
    rules += ' Rd9';
    rules += ' Yd9';
    rules += ' Xb9';
    rules += ' _2b9';
    rules += ' g99';
    rules += ' _je9';
    rules += ' __ca9';
    if (props.isHidden) rules += ' _6b9';
    return rules;
};
function $03960a2740ca2b19$var$ExpandableRowChevron(props1) {
    let expandButtonRef = (0, $iOVFT$useRef)(null);
    let [fullProps, ref] = (0, $iOVFT$useContextProps)({
        ...props1,
        slot: 'chevron'
    }, expandButtonRef, (0, $iOVFT$ButtonContext));
    let { isExpanded: isExpanded, isDisabled: isDisabled, scale: scale, isHidden: isHidden } = fullProps;
    let { direction: direction } = (0, $iOVFT$useLocale)();
    isDisabled = isDisabled || isHidden;
    return /*#__PURE__*/ (0, $iOVFT$jsx)((0, $iOVFT$Button), {
        ...props1,
        ref: ref,
        slot: "chevron",
        // Override tabindex so that grid keyboard nav skips over it. Needs -1 so android talkback can actually "focus" it
        excludeFromTabOrder: (0, $iOVFT$isAndroid)() && !isDisabled,
        preventFocusOnPress: true,
        className: (renderProps)=>$03960a2740ca2b19$var$expandButton({
                ...renderProps,
                isExpanded: isExpanded,
                isRTL: direction === 'rtl',
                scale: scale,
                isHidden: isHidden
            }),
        children: /*#__PURE__*/ (0, $iOVFT$jsx)((0, $4b69f02ec06b9226$export$2e2bcd8739ae039), {
            className: function anonymous(props) {
                let rules = " ";
                if (props.direction === "rtl") {
                    rules += ' -Z4Pn4c-a9';
                    rules += ' __Ha9';
                } else if (props.direction === "ltr") {
                    rules += ' -Z4Pn4c-b9';
                    rules += ' __Ha9';
                }
                if (props.direction === "rtl") {
                    rules += ' -_04Pn4c-a9';
                    rules += ' __Ha9';
                } else if (props.direction === "ltr") {
                    rules += ' -_04Pn4c-b9';
                    rules += ' __Ha9';
                }
                rules += ' -_8sjo0b-t5ZbAob9';
                return rules;
            }({
                direction: direction
            })
        })
    });
}
/**
 * A tree view provides users with a way to navigate nested hierarchical information.
 */ const $03960a2740ca2b19$export$6940b0d9c820eca7 = /*#__PURE__*/ (0, $iOVFT$forwardRef)($03960a2740ca2b19$var$TreeView);


export {$03960a2740ca2b19$export$6e77ea6719814e9c as TreeViewItem, $03960a2740ca2b19$export$9a5779ed3fade674 as TreeViewItemContent, $03960a2740ca2b19$export$6940b0d9c820eca7 as TreeView};
//# sourceMappingURL=TreeView.mjs.map
